==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nb.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Den angitte operatøren er ugyldig",
    "The given regular expression is invalid" : "Det angitte regulære uttrykket er ugyldig",
    "The given file size is invalid" : "Den angitte filstørrelsen er ugyldig",
    "The given tag id is invalid" : "Den angitte merkelappen er ugyldig",
    "The given IP range is invalid" : "Den angitte ip rangen er ugyldig",
    "The given IP range is not valid for IPv4" : "Den angitte ip rangen er ugyldig for IPv4",
    "The given IP range is not valid for IPv6" : "Den angitte ip rangen er ugyldig for IPv6",
    "The given time span is invalid" : "Den angitte tidsrammen er ugyldig",
    "The given start time is invalid" : "Den angitte starttiden er ugyldig",
    "The given end time is invalid" : "Den angitte slutttiden er ugyldig",
    "The given group does not exist" : "Den angitte brukergruppen finnes ikke",
    "File" : "Fil",
    "File created" : "Fil laget",
    "File updated" : "Fil oppdatert",
    "File renamed" : "Fil har fått nytt navn",
    "File deleted" : "Fil slettet",
    "File accessed" : "Fil åpnet",
    "File copied" : "Fil kopiert",
    "Tag assigned" : "Tildelt etikett",
    "Someone" : "Noen",
    "%s created %s" : "%s laget %s",
    "%s modified %s" : "%s endret %s",
    "%s deleted %s" : "%s slettet %s",
    "%s accessed %s" : "%s åpnet %s",
    "%s renamed %s" : "%s gitt nytt navn %s",
    "%s copied %s" : "%s kopiert %s",
    "%s assigned %s to %s" : "%s tildelt %s til %s",
    "Operation #%s does not exist" : "Handlingen #%s finnes ikke",
    "Entity %s does not exist" : "Enheten %s eksisterer ikke",
    "Entity %s is invalid" : "Enheten %s er ugyldig",
    "No events are chosen." : "Ingen hendelser er valgt.",
    "Entity %s has no event %s" : "Enheten %s har ingen hendelser %s",
    "Operation %s does not exist" : "Handlingen %s finnes ikke",
    "Operation %s is invalid" : "Handlingen %s er ugyldig",
    "At least one check needs to be provided" : "Minst èn sjekk må gis",
    "The provided operation data is too long" : "De oppgitte operasjonsdataene er for lange",
    "Invalid check provided" : "Ugyldig sjekk gitt",
    "Check %s does not exist" : "Sjekk %s finnes ikke",
    "Check %s is invalid" : "Sjekk %s er ugyldig",
    "Check %s is not allowed with this entity" : "Sjekk %s er ikke tillatt med denne hendelsen",
    "The provided check value is too long" : "Den oppgitte sjekkverdien er for lang",
    "Check #%s does not exist" : "Sjekk #%s finnes ikke",
    "Check %s is invalid or does not exist" : "Sjekk %s er ugyldig eller finnes ikke",
    "Flow" : "Flyt",
    "Nextcloud workflow engine" : "Nextcloud arbeidsflytsmotor",
    "Select a filter" : "Velg et filter",
    "Select a comparator" : "Velg en komparator",
    "Remove filter" : "Fjern filter",
    "Audio" : "Lyd",
    "Folder" : "Mappe",
    "Images" : "Bilder",
    "Office documents" : "Office dokumenter",
    "PDF documents" : "PDF dokumenter",
    "Video" : "Video",
    "Custom MIME type" : "Egendefinert MIME-type",
    "Custom mimetype" : "Egendefinert MIME-type",
    "Select a file type" : "Velg filtype",
    "e.g. httpd/unix-directory" : "f.eks. httpd/unix-mappe",
    "Please enter a valid time span" : "Vennligst skriv inn en gyldig tidsperiode",
    "Files WebDAV" : "Filer WebDAV",
    "Custom URL" : "Egendefinert URL",
    "Select a request URL" : "Velg en forespurt URL",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Skrivebordsklient",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook tillegg",
    "Custom user agent" : "Egendefinert brukeragent",
    "Select a user agent" : "Velg en brukeragent",
    "Select groups" : "Velg grupper",
    "Groups" : "Grupper",
    "Type to search for group …" : "Skriv for å søke etter gruppe...",
    "Select a trigger" : "Velg en utløser",
    "At least one event must be selected" : "Minst èn hendelse må velges",
    "Add new flow" : "Legg til ny flyt",
    "The configuration is invalid" : "Konfigurasjonen er ugyldig",
    "Active" : "Aktiv",
    "Save" : "Lagre",
    "When" : "Når",
    "and" : "og",
    "Add a new filter" : "Legg til nytt filter",
    "Cancel" : "Avbryt",
    "Delete" : "Slett",
    "Available flows" : "Tilgjengelige flyt",
    "For details on how to write your own flow, check out the development documentation." : "For informasjon om hvordan du skriver din egen flyt, sjekk ut utviklingsdokumentasjonen.",
    "No flows installed" : "Ingen flyter installert",
    "Ask your administrator to install new flows." : "Be administratoren om å installere nye flyter.",
    "More flows" : "Flere flyt",
    "Browse the App Store" : "Utforsk appbutikken",
    "Show less" : "Vis mindre",
    "Show more" : "Vis mer",
    "Configured flows" : "Konfigurerte flyt",
    "Your flows" : "Dine flyt",
    "No flows configured" : "Ingen flyter konfigurert",
    "matches" : "passer",
    "does not match" : "passer ikke",
    "is" : "er",
    "is not" : "er ikke",
    "File name" : "Filnavn",
    "File MIME type" : "Filens MIME-type",
    "File size (upload)" : "Filstørrelse (opplasting)",
    "less" : "mindre",
    "less or equals" : "mindre eller lik",
    "greater or equals" : "større eller lik",
    "greater" : "større",
    "Request remote address" : "Be om ekstern adresse",
    "matches IPv4" : "passer IPv4",
    "does not match IPv4" : "passer ikke IPv4",
    "matches IPv6" : "passer IPv6",
    "does not match IPv6" : "passer ikke IPv6",
    "File system tag" : "Filsystem-merkelapp",
    "is tagged with" : "er merket med",
    "is not tagged with" : "er ikke merket med",
    "Request URL" : "Ønsk en URL",
    "Request time" : "Ønsket tidspunkt",
    "between" : "mellom",
    "not between" : "ikke mellom",
    "Request user agent" : "Ønsket brukeragent",
    "Group membership" : "Gruppemedlemskap",
    "is member of" : "er medlem av",
    "is not member of" : "er ikke medlem av"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/nb.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Den angitte operatøren er ugyldig",
    "The given regular expression is invalid" : "Det angitte regulære uttrykket er ugyldig",
    "The given file size is invalid" : "Den angitte filstørrelsen er ugyldig",
    "The given tag id is invalid" : "Den angitte merkelappen er ugyldig",
    "The given IP range is invalid" : "Den angitte ip rangen er ugyldig",
    "The given IP range is not valid for IPv4" : "Den angitte ip rangen er ugyldig for IPv4",
    "The given IP range is not valid for IPv6" : "Den angitte ip rangen er ugyldig for IPv6",
    "The given time span is invalid" : "Den angitte tidsrammen er ugyldig",
    "The given start time is invalid" : "Den angitte starttiden er ugyldig",
    "The given end time is invalid" : "Den angitte slutttiden er ugyldig",
    "The given group does not exist" : "Den angitte brukergruppen finnes ikke",
    "File" : "Fil",
    "File created" : "Fil laget",
    "File updated" : "Fil oppdatert",
    "File renamed" : "Fil har fått nytt navn",
    "File deleted" : "Fil slettet",
    "File accessed" : "Fil åpnet",
    "File copied" : "Fil kopiert",
    "Tag assigned" : "Tildelt etikett",
    "Someone" : "Noen",
    "%s created %s" : "%s laget %s",
    "%s modified %s" : "%s endret %s",
    "%s deleted %s" : "%s slettet %s",
    "%s accessed %s" : "%s åpnet %s",
    "%s renamed %s" : "%s gitt nytt navn %s",
    "%s copied %s" : "%s kopiert %s",
    "Operation #%s does not exist" : "Handlingen #%s finnes ikke",
    "Entity %s is invalid" : "Enheten %s er ugyldig",
    "Entity %s does not exist" : "Enheten %s eksisterer ikke",
    "No events are chosen." : "Ingen hendelser er valgt.",
    "Entity %s has no event %s" : "Enheten %s har ingen hendelser %s",
    "The provided operation data is too long" : "De oppgitte operasjonsdataene er for lange",
    "Operation %s is invalid" : "Handlingen %s er ugyldig",
    "Operation %s does not exist" : "Handlingen %s finnes ikke",
    "At least one check needs to be provided" : "Minst èn sjekk må gis",
    "Invalid check provided" : "Ugyldig sjekk gitt",
    "The provided check value is too long" : "Den oppgitte sjekkverdien er for lang",
    "Check %s is invalid" : "Sjekk %s er ugyldig",
    "Check %s does not exist" : "Sjekk %s finnes ikke",
    "Check %s is not allowed with this entity" : "Sjekk %s er ikke tillatt med denne hendelsen",
    "Check #%s does not exist" : "Sjekk #%s finnes ikke",
    "Check %s is invalid or does not exist" : "Sjekk %s er ugyldig eller finnes ikke",
    "Flow" : "Flyt",
    "Nextcloud workflow engine" : "Nextcloud arbeidsflytsmotor",
    "Select a filter" : "Velg et filter",
    "Select a comparator" : "Velg en komparator",
    "Remove filter" : "Fjern filter",
    "Audio" : "Lyd",
    "Folder" : "Mappe",
    "Images" : "Bilder",
    "Office documents" : "Office dokumenter",
    "PDF documents" : "PDF dokumenter",
    "Video" : "Video",
    "Custom MIME type" : "Egendefinert MIME-type",
    "Select a file type" : "Velg filtype",
    "e.g. httpd/unix-directory" : "f.eks. httpd/unix-mappe",
    "Please enter a valid time span" : "Vennligst skriv inn en gyldig tidsperiode",
    "Files WebDAV" : "Filer WebDAV",
    "Custom URL" : "Egendefinert URL",
    "Select a request URL" : "Velg en forespurt URL",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Skrivebordsklient",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook tillegg",
    "Custom user agent" : "Egendefinert brukeragent",
    "Select a user agent" : "Velg en brukeragent",
    "Select groups" : "Velg grupper",
    "Groups" : "Grupper",
    "Select a trigger" : "Velg en utløser",
    "At least one event must be selected" : "Minst èn hendelse må velges",
    "Add new flow" : "Legg til ny flyt",
    "The configuration is invalid" : "Konfigurasjonen er ugyldig",
    "Active" : "Aktiv",
    "Save" : "Lagre",
    "When" : "Når",
    "and" : "og",
    "Add a new filter" : "Legg til nytt filter",
    "Cancel" : "Avbryt",
    "Delete" : "Slett",
    "Available flows" : "Tilgjengelige flyt",
    "For details on how to write your own flow, check out the development documentation." : "For informasjon om hvordan du skriver din egen flyt, sjekk ut utviklingsdokumentasjonen.",
    "No flows installed" : "Ingen flyter installert",
    "Ask your administrator to install new flows." : "Be administratoren om å installere nye flyter.",
    "More flows" : "Flere flyt",
    "Browse the App Store" : "Utforsk appbutikken",
    "Show less" : "Vis mindre",
    "Show more" : "Vis mer",
    "Configured flows" : "Konfigurerte flyt",
    "Your flows" : "Dine flyt",
    "No flows configured" : "Ingen flyter konfigurert",
    "matches" : "passer",
    "does not match" : "passer ikke",
    "is" : "er",
    "is not" : "er ikke",
    "File name" : "Filnavn",
    "File MIME type" : "Filens MIME-type",
    "File size (upload)" : "Filstørrelse (opplasting)",
    "less" : "mindre",
    "less or equals" : "mindre eller lik",
    "greater or equals" : "større eller lik",
    "greater" : "større",
    "Request remote address" : "Be om ekstern adresse",
    "matches IPv4" : "passer IPv4",
    "does not match IPv4" : "passer ikke IPv4",
    "matches IPv6" : "passer IPv6",
    "does not match IPv6" : "passer ikke IPv6",
    "File system tag" : "Filsystem-merkelapp",
    "is tagged with" : "er merket med",
    "is not tagged with" : "er ikke merket med",
    "Request URL" : "Ønsk en URL",
    "Request time" : "Ønsket tidspunkt",
    "between" : "mellom",
    "not between" : "ikke mellom",
    "Request user agent" : "Ønsket brukeragent",
    "Group membership" : "Gruppemedlemskap",
    "is member of" : "er medlem av",
    "is not member of" : "er ikke medlem av",
    "Type to search for group …" : "Skriv for å søke etter gruppe..."
},
"nplurals=2; plural=(n != 1);");
